@@ -36,6 +36,7 @@ class SplunkBackend(TextQueryBackend):
     escape_char : ClassVar[str] = "\\"
     wildcard_multi : ClassVar[str] = "*"
     wildcard_single : ClassVar[str] = "*"
+    add_escaped : ClassVar[str] = "\\"
 
     re_expression : ClassVar[str] = "{regex}"
     re_escape_char : ClassVar[str] = "\\"
@@ -56,8 +57,8 @@ class SplunkBackend(TextQueryBackend):
     field_in_list_expression : ClassVar[str] = "{field} IN ({list})"
     list_separator : ClassVar[str] = ", "
 
-    unbound_value_str_expression : ClassVar[str] = '"*{value}*"'
-    unbound_value_num_expression : ClassVar[str] = '*{value}*'
+    unbound_value_str_expression : ClassVar[str] = '"{value}"'
+    unbound_value_num_expression : ClassVar[str] = '{value}'
     unbound_value_re_expression : ClassVar[str] = '{value}'
 
     deferred_start : ClassVar[str] = "\n| "
